%This is a Matlab script developed by Konstantinos Glynis
%based on the analysis of (https://www.itia.ntua.gr/el/docinfo/2079/)
%K. Glynis, T. Iliopoulou, P. Dimitriadis, and D. Koutsoyiannis, Stochastic investigation 
%of daily air temperature extremes from a global ground station network

clc; clear all; close all;

tail = 2; %Lower tail
load('MonteCarlo_timeseries_Tavg.mat')
size1 = size(T,1);
size2 = size(T,2);
start_year = 1881;
end_year = 1988;
Kp_alpha = NaN(size1,end_year-start_year+1);
Kp_beta = NaN(size1,end_year-start_year+1);
Kp_gamma = NaN(size1,end_year-start_year+1);
Kp_delta = NaN(size1,end_year-start_year+1);

for i = 1:size1; %for each timeseries
    for j = 1:(round(size2/365.25,0)-29); %for each 30-year period
        point1 = round((j-1)*365.25+1,0);
        point2 = min(round(point1+29*365.25,0),size2);
        pos = j;
        [Kp_alpha(i,pos),Kp_beta(i,pos),Kp_gamma(i,pos),Kp_delta(i,pos)] = K_calc_mc(T(i,point1:point2),tail);
    end
end

y_alpha = new_organize(Kp_alpha,end_year-start_year+1);
y_beta = new_organize(Kp_beta,end_year-start_year+1);
y_gamma = new_organize(Kp_gamma,end_year-start_year+1);
y_delta = new_organize(Kp_delta,end_year-start_year+1);

years = [start_year:1:end_year];
figure(1)
hold on; grid on;
for i=1:end_year-start_year+1;
    plot3([years(i) years(i) years(i)],[4.95 4.95 4.95],y_alpha(:,i),'-*b');
    plot3([years(i) years(i) years(i)],[16.49 16.49 16.49],y_beta(:,i),'-*b');
    plot3([years(i) years(i) years(i)],[32.98 32.98 32.98],y_gamma(:,i),'-*b');
    plot3([years(i) years(i) years(i)],[49.47 49.47 49.47],y_delta(:,i),'-*b');
end
xlim([1881 1988]);
zlim([2 5]);
title(['Monte-Carlo | Lower tail of Tavg | Number of virtual stations: ', num2str(size1)]);
xlabel('Start of 30 year period');
ylabel('Return period (years)');
hold off

toc;